@@ -4,6 +4,8 @@ pub mod errors;
 mod parse_to_ast;
 mod parse_to_value;
 mod scanner;
+#[cfg(feature = "serde")]
+mod serde;
 pub mod tokens;
 mod value;
 
@@ -11,3 +13,6 @@ pub use parse_to_ast::*;
 pub use parse_to_value::*;
 pub use scanner::*;
 pub use value::*;
+
+#[cfg(feature = "serde")]
+pub use serde::*;
