@@ -137,9 +137,9 @@ mod tests {
   #[test]
   fn error_unexpected_token() {
     let err = parse_to_value("{\n  \"a\":\u{200b}5 }").err().unwrap();
-    assert_eq!(err.range.start_line, 1);
-    assert_eq!(err.range.start, 8);
-    assert_eq!(err.range.end, 11);
+    assert_eq!(err.range.start.line, 1);
+    assert_eq!(err.range.start.index, 8);
+    assert_eq!(err.range.end.index, 11);
     assert_eq!(err.message, "Unexpected token");
   }
 }
